@@ -2,10 +2,10 @@ from spider import app
 from raspberry_jam import helpers, app
 import soundcloud, pprint
 
-raspberry_jam = '00d1b88836fe1fd24a9753ab974c87b1'
-client = soundcloud.Client(client_id=raspberry_jam)
+client_string = '00d1b88836fe1fd24a9753ab974c87b1'
+client = soundcloud.Client(client_id=client_string)
 
-# Returns latest 10 tracks from the SoundCloud API as string
+# Returns latest 200 tracks from the SoundCloud API as string
 def fetch_tracks():
     try:
         tracks = client.get('/tracks', order='latest', limit=200)
@@ -21,3 +21,6 @@ def lookup_tracks(requested_ids):
         return tracks
     except Exception as e:
         app.logger.error('Err: %s' % e)
+
+def client_id():
+    return client_string
